MzFont: Sharp MZ TrueType font generator — MzFont 0.0.1 documentation

# MzFont: Sharp MZ TrueType font generator

This package provides a way to generate and test several Sharp MZ TrueType fonts.

## Quick start

Download the Sharp MZ character and monitor ROMs and run the following command.

    mzfont make mz700fon.int 1z-013a.rom ~/.local/share/fonts/SharpMZ.ttf
    fc-cache -fv ~/.local/share/fonts

Open a new terminal that uses the Sharp MZ font.

    foot -f SharpMZ

In the newly opened terminal, run the test.

    mzfont test

## Fonts

Both methods create a font that contains four character sets of size 256 in the UTF-8 Private Use Area. The normal and alternative character sets including control characters are stored at 0xe000 and 0xe100 respectively. The complete normal and alternative character sets are stored at 0xe200 and 0xe300 respectively. The test subcommand shows all four character sets.

The make subcommand leaves the default font unchanged.

The default subcommand additionally changes the default font, uses square characters and removes line spacing.

Please see ReadTheDocs for the latest documentation.

Contents:

- Installation
  - From source
- Usage
- Command Line Interface
  - Positional Arguments
  - Named Arguments
  - Sub-commands
- Contributors